package com.xinelu.manage.service.patientnodeparamslog.impl;

import com.xinelu.manage.domain.patientnodeparamslog.PatientNodeParamsLog;
import com.xinelu.manage.mapper.patientnodeparamslog.PatientNodeParamsLogMapper;
import com.xinelu.manage.service.patientnodeparamslog.IPatientNodeParamsLogService;
import java.time.LocalDateTime;
import java.util.List;
import javax.annotation.Resource;
import org.springframework.stereotype.Service;

/**
 * 患者节点参数历史记录Service业务层处理
 *
 * @author haown
 * @date 2024-05-20
 */
@Service
public class PatientNodeParamsLogServiceImpl implements IPatientNodeParamsLogService {
    @Resource
    private PatientNodeParamsLogMapper patientNodeParamsLogMapper;

    /**
     * 查询患者节点参数历史记录
     *
     * @param id 患者节点参数历史记录主键
     * @return 患者节点参数历史记录
     */
    @Override
    public PatientNodeParamsLog selectPatientNodeParamsLogById(Long id) {
        return patientNodeParamsLogMapper.selectPatientNodeParamsLogById(id);
    }

    /**
     * 查询患者节点参数历史记录列表
     *
     * @param patientNodeParamsLog 患者节点参数历史记录
     * @return 患者节点参数历史记录
     */
    @Override
    public List<PatientNodeParamsLog> selectPatientNodeParamsLogList(PatientNodeParamsLog patientNodeParamsLog) {
        return patientNodeParamsLogMapper.selectPatientNodeParamsLogList(patientNodeParamsLog);
    }

    /**
     * 新增患者节点参数历史记录
     *
     * @param patientNodeParamsLog 患者节点参数历史记录
     * @return 结果
     */
    @Override
    public int insertPatientNodeParamsLog(PatientNodeParamsLog patientNodeParamsLog) {
                patientNodeParamsLog.setCreateTime(LocalDateTime.now());
            return patientNodeParamsLogMapper.insertPatientNodeParamsLog(patientNodeParamsLog);
    }

    /**
     * 修改患者节点参数历史记录
     *
     * @param patientNodeParamsLog 患者节点参数历史记录
     * @return 结果
     */
    @Override
    public int updatePatientNodeParamsLog(PatientNodeParamsLog patientNodeParamsLog) {
                patientNodeParamsLog.setUpdateTime(LocalDateTime.now());
        return patientNodeParamsLogMapper.updatePatientNodeParamsLog(patientNodeParamsLog);
    }

    /**
     * 批量删除患者节点参数历史记录
     *
     * @param ids 需要删除的患者节点参数历史记录主键
     * @return 结果
     */
    @Override
    public int deletePatientNodeParamsLogByIds(Long[] ids) {
        return patientNodeParamsLogMapper.deletePatientNodeParamsLogByIds(ids);
    }

    /**
     * 删除患者节点参数历史记录信息
     *
     * @param id 患者节点参数历史记录主键
     * @return 结果
     */
    @Override
    public int deletePatientNodeParamsLogById(Long id) {
        return patientNodeParamsLogMapper.deletePatientNodeParamsLogById(id);
    }
}
